import React, { useRef, useState } from 'react'
import { Row, Col, Space } from 'antd';
import { link, register } from '@/assets/images';
import { Form, Input, Button, Radio } from '@arco-design/web-react';
import ArcoUpload from '@/components/ArcoUpload';
import { Scrollbars } from "react-custom-scrollbars";
import ReviewProgress from './ReviewProgress';

const RadioGroup = Radio.Group;
const FormItem = Form.Item;
const TextArea = Input.TextArea;

export default function Examine(props) {
  const formRef = useRef();
  const [result, setResult] = useState()
  const infoData = {
    result: '化解不成功',
    time: '2024-7-21 12:00',
    people: '白云区新市街市场监管所',
    person: '张晓霞',
    reason: '当事人拒绝参加调解，对调解工作极为抗拒',
    opinion: `针对该事项，我部门高度重视并立即启动了调解程序。然而，在调解过程中遇到的主要困难是当事人李晓明未能积极配合我们的工作，具体表现为：
    1、拒绝提供必要的证据材料；
    2、不接听我们拨打的相关电话；
    3、拒绝到场参加任何调解行为
    由于上述原因，我们目前无法进一步查清事实真相，也无法制定出切实可行的解决方案。为了保障当事人的合法权益得到维护，已引导当事人走司法途径，目前已在法院立案，特申请结案。`,
    isProceeding: '是',
    proceeding: '（粤）云调20240811号'
  }

  const handleSubmit = () => {

  }

  return (
    <div className='dataSync'>
      <div className='dataSync-noBackTabPage'>
        <Scrollbars style={{ height: '100%' }} autoHide>
          <div className='whiteBox'>
            <Space size='small'>
              <div className='MediationInfo-subTitle' style={{ marginTop: '-8px' }}></div><h5>结案申请</h5>
            </Space>
            <Row gutter={[16, 16]}>
              <Col span={24}>
                <div><div className="title-text">化解结果</div></div>
                <div>{infoData?.result || '-'}</div>
              </Col>
              <Col span={24}>
                <div><div className="title-text">无法化解理由</div></div>
                <div>{infoData?.reason || '-'}</div>
              </Col>
              <Col span={24}>
                <div><div className="title-text">结案意见</div></div>
                <div>{infoData?.opinion || '-'}</div>
              </Col>
              <Col span={24}>
                <div><div className="title-text">是否转诉讼案件</div></div>
                <div>{infoData?.isProceeding || '-'}</div>
              </Col>
              <Col span={24}>
                <div><div className="title-text">诉讼案号</div></div>
                <div>{infoData?.proceeding || '-'}</div>
              </Col>
              <Col span={24}>
                <div><div className="title-text">申请时间</div></div>
                <div>{infoData?.time || '-'}</div>
              </Col>
              <Col span={24}>
                <div><div className="title-text">申请人</div></div>
                <div>{infoData?.people}&nbsp;&nbsp;{infoData?.person}<img src={register} alt="" className="title-register" /></div>
              </Col>
            </Row>
          </div>
          <div style={{ display: 'flex', marginTop: '8px' }}>
            <div className='whiteBox' style={{ flex: 1, marginRight: '8px' }}>
              <Space size='small'>
                <div className='MediationInfo-subTitle' style={{ marginTop: '-8px' }}></div><h5>审核</h5>
              </Space>
              <Form
                ref={formRef}
                layout='vertical'
                requiredSymbol={false}
                initialValues={{
                }}//默认值
                scrollToFirstError
              >
                <Row>
                  <Col span={24}>
                    <FormItem
                      label={(<div style={{ display: 'flex' }}>审核结果</div>)}
                      field='result'
                    >
                      <RadioGroup
                        direction='vertical'
                        options={[
                          {
                            label: '同意',
                            value: 1
                          },
                          {
                            label: '不同意',
                            value: 0
                          },
                        ]}
                        onChange={(v) => { setResult(v) }}
                      >
                      </RadioGroup>
                    </FormItem>
                  </Col>
                  {result === 0 &&
                    <>
                      <Col span={24}>
                        <FormItem
                          label={(<div style={{ display: 'flex' }}>理由说明<div className="must">必填</div></div>)}
                          field='trueName'
                          rules={[{ required: true, message: '请选择理由说明' }]}
                        >
                          <RadioGroup direction='vertical' options={[
                            {
                              label: '材料不完整',
                              value: '0'
                            },
                            {
                              label: '办理流程有问题',
                              value: '1'
                            },
                            {
                              label: '当事人不满意调解结果',
                              value: '2'
                            },
                            {
                              label: '其他',
                              value: '3'
                            },
                          ]}>
                          </RadioGroup>
                        </FormItem>
                      </Col>
                      <Col span={24}>
                        <FormItem
                          label=' '
                          field='luyou'
                          rules={[{ required: true, message: '理由不能为空' }]}
                        >
                          <TextArea
                            autoSize={{ minRows: 4, maxRows: 8 }}
                            placeholder='请填写回退的具体理由'
                          />
                        </FormItem>
                      </Col>
                      <Col span={24} className="doubleFile">
                        <ArcoUpload
                          params={{
                            action: ``,
                          }}
                          field='file'
                          label='附件材料'
                        />
                      </Col>
                    </>
                  }
                </Row>
              </Form>
              <div className='dialogFooter'>
                <Button
                  type="primary"
                  className="dialogPrimary"
                  onClick={handleSubmit}
                >
                  提交
                </Button>
              </div>
            </div>
            <div className='whiteBox' style={{ width: '400px' }}>
              <Space size='small'>
                <div className='MediationInfo-subTitle' style={{ marginTop: '-8px' }}></div><h5>审核进度</h5>
              </Space>
              <ReviewProgress />
            </div>
          </div>

        </Scrollbars>
      </div>
    </div>
  )
}
